# Introduction to Hypothesis Test
#
# Authors: Harold Valdivia-Garica
#          Mei Nagappan

library(ggplot2)

# This function plot the histogram
# using the ggplot2 library and only
# will work with the dataset used in 
# this file.
my.hist = function(ds){
	p = ggplot(ds, aes(x=loc, fill=type)) +
		geom_histogram( alpha=0.4, position="identity",bins = 50, color="black")
	plot(p)
}
setwd("/Users/meido/Desktop/Research/Courses/Waterloo/CS846/stats-for-se")
do.main  = function(){
	# Read the dataset
    # ================
	ds = read.csv(file="hypothesis-example.csv")
	head(ds)  # See the first 10 rows
	
	# Split by file type
	# ==================
	dspython = ds[ds$type == "python", ]
	dsjava   = ds[ds$type == "java", ]
	dsc      = ds[ds$type == "C", ]
	
	
	# What is a Hypothesis Test?
	# ==========================
	
	# Display the mean and distribution
	# of python, java and C files
	# =================================
	par(mfrow=c(3,1))
	hist(dspython$loc)
	mean(dspython$loc)
	
	hist(dsjava$loc)
	mean(dsjava$loc)
	
	hist(dsc$loc)
	mean(dsc$loc)
	
	# Show distributions of python vs. C
	my.hist(rbind(dspython, dsc))
	
	# Show distributions of java vs. C
	my.hist(rbind(dsjava, dsc))

	# Show distributions of python vs. java
	my.hist(rbind(dspython, dsjava))
	

    # T-test
    # Are java-files != python-files?
	#  H0: J = P
	#  Ha: J != P
    t.test(dsjava$loc, dspython$loc ,alternative = "two.sided")      
    
    # Since we know they are not equal, let's find which is greater
    #  H0: J = P
    #  Ha: J > P
    t.test(dsjava$loc, dspython$loc ,alternative = "greater")      
    
    #  H0: J = P
    #  Ha: J < p
    t.test(dsjava$loc, dspython$loc ,alternative = "less") 
    
    # Note: t-test assumes that the two samples are normal distributed
    # If they are not normal, t-test should not be usedß
    
    # Check normality
    # ===============
    print(shapiro.test(dsjava$loc))
    print(shapiro.test(dspython$loc))
  
    # Use a non-parametric test
    # Wilcoxon test doesn't assume any distribution
    # =============================================
    # Are java-files != python-files?
    wilcox.test(dsjava$loc, dspython$loc ,alternative = "two.sided")      
    
    # Since we know they are not equal, let's find which is greater
    wilcox.test(dsjava$loc, dspython$loc ,alternative = "greater")      
    wilcox.test(dsjava$loc, dspython$loc ,alternative = "less") 
    
}


do.main()